; Print Relative
; Sets BricsCAD's Print Output Folder to be relative to the current drawing folder

(defun C:PrintRelative ( / SubFolder PrintFolder PrintName flag FullPrintName filenm)
	(setq SubFolder "PDF") ; define the subfolder. Set to "" if you prefer to use the current .dwg folder
	(setq PrintFolder (strcat (getvar 'DWGPREFIX) subfolder)) ; define the print folder we want to use
	(setq PrintName (strcat (vl-filename-base (getvar 'DWGNAME)) "-" (getvar 'CTAB))) ; Set the name for the print
	
	; Check our chosen folder exists
	(cond 
		((not (vl-file-directory-p printfolder)) ; If the folder doesn't exist
			(setq flag (vl-mkdir printfolder)) ; Create it. Flag will be set to T if successful
		)
		(T (setq flag T)) ; Folder already exists
	)
	
	; Tell the user where we are printing
	(cond
		(flag (princ (strcat "\nPrinting to: " printfolder))) ; Use chosen folder
		(T (princ (strcat "\nCouldn't set Print folder to: " PrintFolder " Printing to: " (setq PrintFolder (getvar 'PlotOutputPath)) ))) ; alternate folder
	)
	(setq FullPrintName (strcat PrintFolder "\\" PrintName)) ; Set the folder and filename
	(setq flag nil) ; re-initialse our flag
	
	; BricsCAD doesn't respect EXPERT for printing, so need to check whether the print already exists and attempt to delete ourselves 
	(cond 
		((setq filenm (findfile (strcat FullPrintName ".pdf"))) ; if the print file already exists
			(setq flag (vl-file-delete filenm)) ; then attempt to delete. Flag will be set to T if successful
		)
		(T (setq flag T)) ; File doesn't exist
	)
	
	; Proceed with Printing provided its ok to do so.
	(cond
		(flag (command "._PLOT" "_No" "" "" "Print As PDF.pc3" FullPrintName "_No" "_Yes"))
		(T (princ (strcat "\nCouldn't print: \"" PrintName ".pdf\" Check if the file is currently OPEN"))) ; i.e. check if the file is currently open in your PDF viewer!
	)
	(prin1)
)